# `aiida-sssp`

This project is archived and has been fully superseded by `aiida-pseudo` which you can find here:

 * [Source code](https://github.com/aiidateam/aiida-pseudo)
 * [PyPI package](https://pypi.org/project/aiida-pseudo/)
